==> styled-bootstrap-0.1.7-1.tgz: package/lib/CLoseIcon/CLoseIcon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteral(['\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-shadow: ', ';\n  opacity: 0.5;\n\n  ', ';\n\n  /* Opinionated: add "hand" cursor to non-disabled .close elements */\n  &:not(:disabled):not(.disabled) {\n    cursor: pointer;\n  }\n\n  padding: 0;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n'], ['\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-shadow: ', ';\n  opacity: 0.5;\n\n  ', ';\n\n  /* Opinionated: add "hand" cursor to non-disabled .close elements */\n  &:not(:disabled):not(.disabled) {\n    cursor: pointer;\n  }\n\n  padding: 0;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import styled from 'styled-components';
import themeProp from '../utils/src/theme';

import { hoverFocus } from '../../src/utils/src';

import { closeFontSize, closeFontWeight, closeColor, closeTextShadow } from './default-theme';

export var StyledCloseIcon = styled.button(_templateObject, themeProp('closeFontSize', closeFontSize), themeProp('closeFontWeight', closeFontWeight), themeProp('closeColor', closeColor), themeProp('closeTextShadow', closeTextShadow), hoverFocus('\n    color: ' + themeProp('closeColor', closeColor) + ';\n    text-decoration: none;\n    opacity: .75;\n  '));

var CloseIcon = function CloseIcon(props) {
  return React.createElement(
    StyledCloseIcon,
    _extends({ 'aria-label': 'Close' }, props),
    React.createElement(
      'span',
      { 'aria-hidden': 'true' },
      props.children || '×'
    )
  );
};

export default CloseIcon;

==> styled-bootstrap-0.1.9.tgz: package/lib/CLoseIcon/CLoseIcon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteral(['\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-shadow: ', ';\n  opacity: 0.5;\n\n  ', ';\n\n  /* Opinionated: add "hand" cursor to non-disabled .close elements */\n  &:not(:disabled):not(.disabled) {\n    cursor: pointer;\n  }\n\n  padding: 0;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n'], ['\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  color: ', ';\n  text-shadow: ', ';\n  opacity: 0.5;\n\n  ', ';\n\n  /* Opinionated: add "hand" cursor to non-disabled .close elements */\n  &:not(:disabled):not(.disabled) {\n    cursor: pointer;\n  }\n\n  padding: 0;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import styled from 'styled-components';
import themeProp from '../utils/theme';

import { hoverFocus } from '../../src/utils/hover';

import { closeFontSize, closeFontWeight, closeColor, closeTextShadow } from './default-theme';

export var StyledCloseIcon = styled.button(_templateObject, themeProp('closeFontSize', closeFontSize), themeProp('closeFontWeight', closeFontWeight), themeProp('closeColor', closeColor), themeProp('closeTextShadow', closeTextShadow), hoverFocus('\n    color: ' + themeProp('closeColor', closeColor) + ';\n    text-decoration: none;\n    opacity: .75;\n  '));

var CloseIcon = function CloseIcon(props) {
  return React.createElement(
    StyledCloseIcon,
    _extends({ 'aria-label': 'Close' }, props),
    React.createElement(
      'span',
      { 'aria-hidden': 'true' },
      props.children || '×'
    )
  );
};

export default CloseIcon;
